MethodChannelLiveActivities class
- Inheritance
-
- Object
- PlatformInterface
- LiveActivitiesPlatform
- MethodChannelLiveActivities
Constructors
Properties
-
frequentPushesEnabled
→ Future<
bool> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onAction
→ Stream<
String> -
no setteroverride
-
onPushToken
→ Stream<
String> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
end(
String id, {LiveActivityData? finalContent, LiveActivityDismissalPolicy policy = LiveActivityDismissalPolicy.immediate}) → Future< bool> -
override
-
endAll(
) → Future< bool> -
override
-
getAllIds(
) → Future< List< String> > -
override
-
getPushToken(
) → Future< String?> -
override
-
isSupported(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
String id, LiveActivityData data, [List< Map< ? actions]) → Future<String, String> >bool> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, LiveActivityData data, [LiveActivityAlert? alert]) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- actionEvents → const EventChannel
- methodChannel → const MethodChannel
- pushTokenEvents → const EventChannel