LiveActivitiesPlatform class abstract

Abstract platform interface for Live Activities + Dynamic Island.

Inheritance
  • Object
  • PlatformInterface
  • LiveActivitiesPlatform
Implementers

Constructors

LiveActivitiesPlatform()

Properties

frequentPushesEnabled Future<bool>
no setter
hashCode int
The hash code for this object.
no setterinherited
onAction Stream<String>
no setter
onPushToken Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

end(String id, {LiveActivityData? finalContent, LiveActivityDismissalPolicy policy = LiveActivityDismissalPolicy.immediate}) Future<bool>
endAll() Future<bool>
getAllIds() Future<List<String>>
getPushToken() Future<String?>
isSupported() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(String id, LiveActivityData data, [List<Map<String, String>>? actions]) Future<bool>
toString() String
A string representation of this object.
inherited
update(String id, LiveActivityData data, [LiveActivityAlert? alert]) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LiveActivitiesPlatform
getter/setter pair