LiveActivityData class
Data model for a Live Activity's content.
Constructors
Properties
- color → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadingIcon → String?
-
final
- progress → double?
-
final
- relevanceScore → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staleMinutes → double?
-
final
- subtitle → String?
-
final
- title → String
-
final
- trailingText → String?
-
final
- wakeScreen → bool
-
final
- wantsPushToken → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited